@@ -111,6 +111,7 @@ class Cache(object):
     set_value = put
     
     def get(self, key, **kw):
+        """Retrieve a cached value from the container"""
         return self._get_value(key, **kw).get_value()
     get_value = get
     
@@ -118,6 +119,7 @@ class Cache(object):
         mycontainer = self._get_value(key, **kw)
         if mycontainer.has_current_value():
             mycontainer.clear_value()
+    remove = remove_value
 
     def _get_value(self, key, **kw):
         if isinstance(key, unicode):
@@ -146,6 +148,7 @@ class Cache(object):
         "cache_manager.get_cache() and/or the Cache constructor instead.")
     
     def clear(self):
+        """Clear all the values from the namespace"""
         self.namespace.remove()
     
     # dict interface
@@ -167,6 +170,13 @@ class Cache(object):
 
 class CacheManager(object):
     def __init__(self, **kwargs):
+        """Initialize a CacheManager object with a set of options
+        
+        Options should be parsed with the
+        :func:`~beaker.util.parse_cache_config_options` function to
+        ensure only valid options are used.
+        
+        """
         self.kwargs = kwargs
         self.caches = {}
         self.regions = kwargs.pop('cache_regions', {})
