@@ -37,15 +37,14 @@ def simple_auto_app(environ, start_response):
     session['value'] += 1
     if environ['PATH_INFO'].startswith('/nosave'):
         session.revert()
-    else:
-        session.save()
     start_response('200 OK', [('Content-type', 'text/plain')])
     return ['The current value is: %d, session id is %s' % (session.get('value', 0),
                                                             session.id)]
 
 
 def test_increment():
-    app = TestApp(SessionMiddleware(simple_app))
+    options = {'session.data_dir':loc, 'session.secret':'blah'}
+    app = TestApp(SessionMiddleware(simple_app, **options))
     res = app.get('/')
     assert 'current value is: 1' in res
     res = app.get('/')
@@ -54,7 +53,8 @@ def test_increment():
     assert 'current value is: 3' in res
 
 def test_increment_auto():
-    app = TestApp(SessionMiddleware(simple_auto_app, auto=True))
+    options = {'session.data_dir':loc, 'session.secret':'blah'}
+    app = TestApp(SessionMiddleware(simple_auto_app, auto=True, **options))
     res = app.get('/')
     assert 'current value is: 1' in res
     res = app.get('/')
@@ -64,8 +64,9 @@ def test_increment_auto():
 
 
 def test_different_sessions():
-    app = TestApp(SessionMiddleware(simple_app))
-    app2 = TestApp(SessionMiddleware(simple_app))
+    options = {'session.data_dir':loc, 'session.secret':'blah'}
+    app = TestApp(SessionMiddleware(simple_app, **options))
+    app2 = TestApp(SessionMiddleware(simple_app, **options))
     res = app.get('/')
     assert 'current value is: 1' in res
     res = app2.get('/')
@@ -78,8 +79,9 @@ def test_different_sessions():
     assert 'current value is: 4' in res
 
 def test_different_sessions_auto():
-    app = TestApp(SessionMiddleware(simple_auto_app, auto=True))
-    app2 = TestApp(SessionMiddleware(simple_auto_app, auto=True))
+    options = {'session.data_dir':loc, 'session.secret':'blah'}
+    app = TestApp(SessionMiddleware(simple_auto_app, auto=True, **options))
+    app2 = TestApp(SessionMiddleware(simple_auto_app, auto=True, **options))
     res = app.get('/')
     assert 'current value is: 1' in res
     res = app2.get('/')
@@ -92,22 +94,21 @@ def test_different_sessions_auto():
     assert 'current value is: 4' in res
 
 def test_nosave():
-    app = TestApp(SessionMiddleware(simple_app))
+    options = {'session.data_dir':loc, 'session.secret':'blah'}
+    app = TestApp(SessionMiddleware(simple_app, **options))
     res = app.get('/nosave')
     assert 'current value is: 1' in res
-    assert [] == res.headers.getall('Set-Cookie')
     res = app.get('/nosave')
     assert 'current value is: 1' in res
     
     res = app.get('/')
     assert 'current value is: 1' in res
-    assert len(res.headers.getall('Set-Cookie')) > 0
     res = app.get('/')
-    assert [] == res.headers.getall('Set-Cookie')
     assert 'current value is: 2' in res
 
 def test_revert():
-    app = TestApp(SessionMiddleware(simple_auto_app, auto=True))
+    options = {'session.data_dir':loc, 'session.secret':'blah'}
+    app = TestApp(SessionMiddleware(simple_auto_app, auto=True, **options))
     res = app.get('/nosave')
     assert 'current value is: 0' in res
     res = app.get('/nosave')
@@ -151,6 +152,7 @@ def test_load_session_by_id():
     # Prior request is now up to 2
     res = app.get('/')
     assert 'current value is: 2' in res
+
     
     
 
